initial gfx906 support

[ROCm/clr commit: 368affcea4]
This commit is contained in:
Siu Chi Chan
2018-04-18 15:27:56 -04:00
committed by Aaron En Ye Shi
parent 9c27cbbd40
commit 04bf6c5109
6 changed files with 29 additions and 8 deletions
@@ -32,7 +32,7 @@ THE SOFTWARE.
#define HALF_SIZE 64 * sizeof(__half)
#define HALF2_SIZE 64 * sizeof(__half2)
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
__global__ void __halfMath(hipLaunchParm lp, __half* A, __half* B, __half* C) {
int tx = threadIdx.x;